# PianoCLI

A playable piano that runs in your terminal.

## Installation

To install the package for development, run:

```bash
pip install pianocli 
````

## Usage

Once installed, you can run the piano from anywhere in your terminal:

```bash
pianocli play
```

To see all available commands, run:

```bash
pianocli --help
```

